@@ -20,14 +20,30 @@
 #include "aac_encode.h"
 #include "wav_header.h"
 
+int g_aac_lib_available = 0;
+
 #ifdef HAVE_LIBFDK_AAC
 
+#if !defined(__APPLE__) && !defined(WIN32)  // LINUX
+ #define aacEncOpen_butt aacEncOpen
+ #define aacEncoder_SetParam_butt aacEncoder_SetParam
+ #define aacEncEncode_butt aacEncEncode
+ #define aacEncInfo_butt aacEncInfo
+ #define aacEncClose_butt aacEncClose
+#endif
+
 
 int aac_enc_init(aac_enc *aac)
 {
     int rc;
     char info_buf[256];
 
+    if (g_aac_lib_available == 0)
+    {
+        snprintf(info_buf, sizeof(info_buf), "libfdk-aac-2.dll not loaded");
+        print_info(info_buf, 1);
+        return 1;
+    }
     
     if(aac->overwrite_aot == 0)
     {
@@ -40,24 +56,24 @@ int aac_enc_init(aac_enc *aac)
     }
 
     
-    aacEncOpen(&aac->handle, 0, aac->channel);
-    aacEncoder_SetParam(aac->handle, AACENC_AOT, aac->aot);
-    aacEncoder_SetParam(aac->handle, AACENC_SAMPLERATE, aac->samplerate);
-    aacEncoder_SetParam(aac->handle, AACENC_CHANNELMODE, aac->channel);
-    aacEncoder_SetParam(aac->handle, AACENC_CHANNELORDER, 1);
-    aacEncoder_SetParam(aac->handle, AACENC_BITRATE, aac->bitrate*1000);
-    aacEncoder_SetParam(aac->handle, AACENC_TRANSMUX, 2);    // taken from the example aac-enc.c
-   // aacEncoder_SetParam(aac->handle, AACENC_AFTERBURNER, 1); // enable after burner
+    aacEncOpen_butt(&aac->handle, 0, aac->channel);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_AOT, aac->aot);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_SAMPLERATE, aac->samplerate);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_CHANNELMODE, aac->channel);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_CHANNELORDER, 1);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_BITRATE, aac->bitrate*1000);
+    aacEncoder_SetParam_butt(aac->handle, AACENC_TRANSMUX, 2);    // taken from the example aac-enc.c
+    aacEncoder_SetParam_butt(aac->handle, AACENC_AFTERBURNER, 1); // enable after burner
 
 
-    if ((rc = aacEncEncode(aac->handle, NULL, NULL, NULL, NULL)) != AACENC_OK)
+    if ((rc = aacEncEncode_butt(aac->handle, NULL, NULL, NULL, NULL)) != AACENC_OK)
     {
         snprintf(info_buf, sizeof(info_buf), "unable to init aac params %d", rc);
         print_info(info_buf, 1);
         return 1;
     }
 
-    aacEncInfo(aac->handle, &aac->info);
+    aacEncInfo_butt(aac->handle, &aac->info);
 
     return 0;
 
@@ -65,6 +81,14 @@ int aac_enc_init(aac_enc *aac)
 
 int aac_enc_reinit(aac_enc *aac)
 {
+    if (g_aac_lib_available == 0)
+    {
+	char info_buf[256];
+        snprintf(info_buf, sizeof(info_buf), "libfdk-aac-2.dll not loaded");
+        print_info(info_buf, 1);
+        return 1;
+    }
+
     if(aac != NULL)
     {
         aac_enc_close(aac);
@@ -75,11 +99,19 @@ int aac_enc_reinit(aac_enc *aac)
 
 void aac_enc_close(aac_enc *aac)
 {
+    if (g_aac_lib_available == 0)
+    {
+	char info_buf[256];
+        snprintf(info_buf, sizeof(info_buf), "libfdk-aac-2.dll not loaded");
+        print_info(info_buf, 1);
+        return;
+    }
+
     while(aac->state == AAC_BUSY)
        ;
 
     if (aac->handle != NULL)
-        aacEncClose(&aac->handle);
+        aacEncClose_butt(&aac->handle);
     
     aac->handle = NULL;
 }
@@ -88,6 +120,14 @@ void aac_enc_close(aac_enc *aac)
 
 int aac_enc_encode(aac_enc *aac, short *pcm_buf, char *enc_buf, int samples, int size)
 {
+    if (g_aac_lib_available == 0)
+    {
+	char info_buf[256];
+        snprintf(info_buf, sizeof(info_buf), "libfdk-aac-2.dll not loaded");
+        print_info(info_buf, 1);
+        return 0;
+    }
+
     int rc;
     AACENC_BufDesc in_buf = { 0 }, out_buf = { 0 };
     AACENC_InArgs in_args = { 0 };
@@ -127,7 +167,7 @@ int aac_enc_encode(aac_enc *aac, short *pcm_buf, char *enc_buf, int samples, int
     aac->state = AAC_BUSY;
     
     
-    if ((rc = aacEncEncode(aac->handle, &in_buf, &out_buf, &in_args, &out_args)) != AACENC_OK)
+    if ((rc = aacEncEncode_butt(aac->handle, &in_buf, &out_buf, &in_args, &out_args)) != AACENC_OK)
     {
         printf("Encoding failed: %d\n", rc);
         return 0;
