@@ -18,11 +18,17 @@
 
 #include "config.h"
 
-#ifdef HAVE_LIBFDK_AAC 
+#ifdef HAVE_LIBFDK_AAC
+
+#if defined(_WIN32) || defined(__APPLE__)
+ #include "aac_dll.h"
+#else
  #include <fdk-aac/aacenc_lib.h>
+#endif
+
 struct aac_enc {
-	HANDLE_AACENCODER handle;
-	AACENC_InfoStruct info;
+    HANDLE_AACENCODER handle;
+    AACENC_InfoStruct info;
     int aot;
     int overwrite_aot;
     int bitrate;
@@ -40,7 +46,10 @@ int aac_enc_init(aac_enc *aac);
 int aac_enc_encode(aac_enc *aac, short *pcm_buf, char *enc_buf, int samples, int size);
 int aac_enc_reinit(aac_enc *aac);
 void aac_enc_close(aac_enc *aac);
-#endif
 
-#endif
+#endif // HAVE_LIBFDK_AAC
+
+extern int g_aac_lib_available;
+
+#endif // AAC_ENCODE_H
 
