@@ -15,6 +15,7 @@
 
 
 #include <stdio.h>
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -28,10 +29,14 @@
  #define IDI_ICON 101 
 #endif
 
-#if ! defined(__APPLE__) && !defined(WIN32)  
+#if !defined(__APPLE__) && !defined(WIN32)
  #include <FL/Fl_File_Icon.H>
 #endif
 
+#if defined(__APPLE__)
+ #include <dlfcn.h>
+#endif
+
 #include "config.h"
 
 #include "cfg.h"
@@ -51,7 +56,6 @@
  #include "aac_encode.h"
 #endif
 
-
 bool record;
 bool recording;
 bool connected;
@@ -83,6 +87,14 @@ flac_enc flac_rec;
 #endif
 
 
+#if defined(__APPLE__) || defined(WIN32)
+ aacEncOpenPtr aacEncOpen_butt;
+ aacEncoder_SetParamPtr aacEncoder_SetParam_butt;
+ aacEncEncodePtr aacEncEncode_butt;
+ aacEncInfoPtr aacEncInfo_butt;
+ aacEncClosePtr aacEncClose_butt;
+#endif
+
 
 int main(int argc, char *argv[])
 {
@@ -96,8 +108,11 @@ int main(int argc, char *argv[])
         //(in case the server closes the connection unexpected)
 #endif
     
-#if ! defined(__APPLE__) && !defined(WIN32)  
+#if ! defined(__APPLE__) && !defined(WIN32)  // LINUX
     Fl_File_Icon::load_system_icons();
+    #ifdef HAVE_LIBFDK_AAC
+	g_aac_lib_available = 1;
+    #endif
 #endif
 
     fl_g = new flgui(); 
@@ -112,8 +127,37 @@ int main(int argc, char *argv[])
     SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_BIG, (LPARAM)bigicon); 
     HANDLE smallicon = LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 16, 16, 0); 
     SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_SMALL, (LPARAM)smallicon); 
+
+    // Load aac library
+    HMODULE hModule = LoadLibrary(TEXT("libfdk-aac-2.dll"));
+    if (hModule != NULL)
+    {
+        aacEncOpen_butt = (aacEncOpenPtr)GetProcAddress(hModule, "aacEncOpen");
+        aacEncoder_SetParam_butt = (aacEncoder_SetParamPtr)GetProcAddress(hModule, "aacEncoder_SetParam");
+        aacEncEncode_butt = (aacEncEncodePtr)GetProcAddress(hModule, "aacEncEncode");
+        aacEncInfo_butt = (aacEncInfoPtr)GetProcAddress(hModule, "aacEncInfo");
+        aacEncClose_butt = (aacEncClosePtr)GetProcAddress(hModule, "aacEncClose");
+        g_aac_lib_available = 1;
+    }
 #endif 
 
+#if defined(__APPLE__)
+    void* dylib = dlopen("libfdk-aac.2.dylib", RTLD_LAZY);
+    if (dylib != NULL)
+    {
+        //typedef AACENC_ERROR(WINAPI *aacEncOpenPtr)(HANDLE_AACENCODER*, UINT, UINT);
+
+        aacEncOpen_butt = (aacEncOpenPtr)dlsym(dylib, "aacEncOpen");
+        aacEncoder_SetParam_butt = (aacEncoder_SetParamPtr)dlsym(dylib, "aacEncoder_SetParam");
+        aacEncEncode_butt = (aacEncEncodePtr)dlsym(dylib, "aacEncEncode");
+        aacEncInfo_butt = (aacEncInfoPtr)dlsym(dylib, "aacEncInfo");
+        aacEncClose_butt = (aacEncClosePtr)dlsym(dylib, "aacEncClose");
+
+        g_aac_lib_available = 1;
+        
+    }
+#endif
+
 
     snprintf(info_buf, sizeof(info_buf), "Starting %s\nWritten by Daniel Nöthen\n"
     	"PayPal: paypal@danielnoethen.de\n", PACKAGE_STRING);
@@ -206,7 +250,10 @@ int main(int argc, char *argv[])
 
 	if(cfg.main.connect_at_startup)
 		button_connect_cb();
-
+    
+    if(cfg.rec.rec_after_launch)
+        button_record_cb();
+        
     snprintf(info_buf, sizeof(info_buf),
             "butt %s started successfully", VERSION);
     print_info(info_buf, 0);
