@@ -137,6 +137,7 @@ int cfg_write_file(char *path)
             "bitrate = %d\n"
             "codec = %s\n"
             "start_rec = %d\n"
+            "rec_after_launch = %d\n"
             "sync_to_hour  = %d\n"
             "split_time = %d\n"
             "filename = %s\n"
@@ -144,6 +145,7 @@ int cfg_write_file(char *path)
             cfg.rec.bitrate,
             cfg.rec.codec,
             cfg.rec.start_rec,
+            cfg.rec.rec_after_launch,
             cfg.rec.sync_to_hour,
             cfg.rec.split_time,
             cfg.rec.filename,
@@ -305,6 +307,10 @@ int cfg_set_values(char *path)
     }
     else //Make sure that also "opus" and "flac" fits into the codec char array
         cfg.audio.codec = (char*)realloc((char*)cfg.audio.codec, 5*sizeof(char));
+
+    if(!strcmp(cfg.audio.codec, "aac") && g_aac_lib_available == 0) {
+        strcpy(cfg.audio.codec, "mp3");
+    }
         
     if(cfg.audio.buffer_ms == -1)
         cfg.audio.buffer_ms = 50;
@@ -329,6 +335,7 @@ int cfg_set_values(char *path)
 
     cfg.rec.bitrate    = cfg_get_int("record", "bitrate");
     cfg.rec.start_rec  = cfg_get_int("record", "start_rec");
+    cfg.rec.rec_after_launch  = cfg_get_int("record", "rec_after_launch");
     cfg.rec.sync_to_hour = cfg_get_int("record", "sync_to_hour");
     cfg.rec.split_time = cfg_get_int("record", "split_time");
     cfg.rec.codec      = cfg_get_str("record", "codec");
@@ -341,6 +348,9 @@ int cfg_set_values(char *path)
     if(cfg.rec.start_rec == -1)
         cfg.rec.start_rec = 0;
 
+    if(cfg.rec.rec_after_launch == -1)
+        cfg.rec.rec_after_launch = 0;
+
     if(cfg.rec.sync_to_hour == -1)
         cfg.rec.sync_to_hour = 0;
 
@@ -355,6 +365,11 @@ int cfg_set_values(char *path)
     else
         cfg.rec.codec = (char*)realloc(cfg.rec.codec, 5*sizeof(char));
 
+
+    if(!strcmp(cfg.rec.codec, "aac") && g_aac_lib_available == 0) {
+        strcpy(cfg.rec.codec, "mp3");
+    }
+
     if(cfg.rec.filename == NULL)
     {
         cfg.rec.filename = (char*)malloc(strlen("rec_%Y%m%d-%H%M%S_%i.mp3")+1);
@@ -665,6 +680,7 @@ int cfg_create_default(void)
             "channel = 2\n"
             "codec = mp3\n"
             "start_rec = 0\n"
+            "rec_after_launch = 0\n"
             "sync_to_hour = 0\n"
             "split_time = 0\n"
             "filename = rec_%%Y%%m%%d-%%H%%M%%S.mp3\n"
